@@ -8,7 +8,7 @@ class APIAccountDefinitions(ResourceList, ResourceCollection):
 
     @classmethod
     def get_resource_name(cls):
-        return 'account_definitions'
+        return 'account-definitions'
 
 
 class APIAccountDefinitionGroups(ResourceList):
